cannotResolve static method
Implementation
static SearchResultException cannotResolve() => SearchResultException(
'Unable to resolve the provided value to a specific [SearchResult].'
);
static SearchResultException cannotResolve() => SearchResultException(
'Unable to resolve the provided value to a specific [SearchResult].'
);