Track class
Metadata about a SoundCloud track.
- Implemented types
- Annotations
-
- @freezed
Constructors
- Track({required Uri? artworkUrl, required String? caption, required bool commentable, required double commentCount, required DateTime createdAt, required String? description, required double downloadCount, required double duration, required double fullDuration, required String? genre, required int id, required String? labelName, required DateTime? lastModified, required String? license, required double likesCount, required Uri permalinkUrl, required double playbackCount, required String? purchaseTitle, required String? purchaseUrl, required double repostsCount, required String? tagList, required String title, required String waveformUrl, required String monetizationModel, required String policy, required MiniUser user})
-
constfactory
-
Track.fromJson(Map<
String, Object?> json) -
factory
Properties
- artworkUrl → Uri?
-
no setterinherited
- caption → String?
-
no setterinherited
- commentable → bool
-
no setterinherited
- commentCount → double
-
no setterinherited
-
copyWith
→ $TrackCopyWith<
Track> -
Create a copy of Track
with the given fields replaced by the non-null parameter values.
no setterinherited
- createdAt → DateTime
-
no setterinherited
- description → String?
-
no setterinherited
- downloadCount → double
-
no setterinherited
- duration → double
-
no setterinherited
- fullDuration → double
-
no setterinherited
- genre → String?
-
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
no setterinherited
- labelName → String?
-
no setterinherited
- lastModified → DateTime?
-
no setterinherited
- license → String?
-
no setterinherited
- likesCount → double
-
no setterinherited
- monetizationModel → String
-
no setterinherited
- permalinkUrl → Uri
-
no setterinherited
- playbackCount → double
-
no setterinherited
- policy → String
-
no setterinherited
- purchaseTitle → String?
-
no setterinherited
- purchaseUrl → String?
-
no setterinherited
- repostsCount → double
-
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tagList → String?
-
no setterinherited
- title → String
-
no setterinherited
- user → MiniUser
-
no setterinherited
- waveformUrl → String
-
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this Track to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited