downloadCount property
The number of times this track has been downloaded through SoundCloud.
Implementation
@JsonKey(defaultValue: 0)
double get downloadCount;
The number of times this track has been downloaded through SoundCloud.
@JsonKey(defaultValue: 0)
double get downloadCount;