fullDuration property

double get fullDuration
override

The full duration of this track.

As some tracks can only be accessed by SoundCloud Go subscribers, this does not necessarily represent the length of playable audio. For that, see duration.

Implementation

double get fullDuration;