monetizationModel property
The monetization model for this track.
I.e., whether the track is supported by advertisements or requires a SoundCloud Go subscription, etc.
Implementation
String get monetizationModel;
The monetization model for this track.
I.e., whether the track is supported by advertisements or requires a SoundCloud Go subscription, etc.
String get monetizationModel;