policy property
The streaming policy for this track.
I.e., whether this track should be monetized by way of advertisements, or snipped so that only SoundCloud Go subscribers can access it.
Implementation
String get policy;
The streaming policy for this track.
I.e., whether this track should be monetized by way of advertisements, or snipped so that only SoundCloud Go subscribers can access it.
String get policy;